@@ -5,13 +5,17 @@ This collects the general public API into a single spot for inclusion, as
 !*/
 
 pub use crate::{
-	bits::Bits,
+	bits::{
+		Bits,
+		BitsMut,
+	},
 	cursor::{
 		Cursor,
 		BigEndian,
 		LittleEndian,
 	},
 	slice::BitSlice,
+	store::BitStore,
 };
 
 #[cfg(any(feature = "alloc", feature = "std"))]
